@@ -26,10 +26,10 @@
 
 This AWS Solutions Construct implements an AWS Events rule and an AWS Lambda function.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
 ```javascript
-const { EventsRuleToLambdaProps, EventsRuleToLambda } = require('@aws-solutions-constructs/aws-events-rule-lambda');
+const { EventsRuleToLambdaProps, EventsRuleToLambda } from '@aws-solutions-constructs/aws-events-rule-lambda';
 
 const props: EventsRuleToLambdaProps = {
     lambdaFunctionProps: {
@@ -42,7 +42,7 @@ const props: EventsRuleToLambdaProps = {
     }
 };
 
-new EventsRuleToLambda(stack, 'test-events-rule-lambda', props);
+new EventsRuleToLambda(this, 'test-events-rule-lambda', props);
 ```
 
 ## Initializer
@@ -82,9 +82,12 @@ Out of the box implementation of the Construct without any override will set the
 
 ### AWS Lambda Function
 
-* Configure least privilege access IAM role for Lambda function
+* Configure limited privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
 * Enable X-Ray Tracing
+* Set Environment Variables
+
+  * AWS_NODEJS_CONNECTION_REUSE_ENABLED (for Node 10.x and higher functions)
 
 ## Architecture
 
